==> terrascan-1.8.0.tar.gz: terrascan-1.8.0/pkg/mapper/iac-providers/arm/config/mssql-server.go <==
/*
    Copyright (C) 2020 Accurics, Inc.

	Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

		http://www.apache.org/licenses/LICENSE-2.0

	Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
*/

package config

import (
	"github.com/accurics/terrascan/pkg/mapper/convert"
	fn "github.com/accurics/terrascan/pkg/mapper/iac-providers/arm/functions"
	"github.com/accurics/terrascan/pkg/mapper/iac-providers/arm/types"
)

const (
	armAdministratorLogin         = "administratorLogin"
	armAdministratorLoginPassword = "administratorLoginPassword"
	armMinimumTLSVersion          = "minimalTlsVersion"
)

const (
	tfAdministratorLogin         = "administrator_login"
	tfAdministratorLoginPassword = "administrator_login_password"
	tfMinimumTLSVersion          = "minimum_tls_version"
)

// MSSQLServerConfig returns config for azurerm_mssql_server
func MSSQLServerConfig(r types.Resource, vars, params map[string]interface{}) map[string]interface{} {
	return map[string]interface{}{
		tfLocation:                   fn.LookUpString(nil, params, r.Location),
		tfName:                       fn.LookUpString(nil, params, r.Name),
		tfTags:                       r.Tags,
		tfAdministratorLogin:         fn.LookUpString(vars, params, convert.ToString(r.Properties, armAdministratorLogin)),
		tfAdministratorLoginPassword: fn.LookUpString(vars, params, convert.ToString(r.Properties, armAdministratorLoginPassword)),
		tfMinimumTLSVersion:          fn.LookUpString(vars, params, convert.ToString(r.Properties, armMinimumTLSVersion)),
	}
}

==> terrascan-1.18.5.tar.gz: terrascan-1.18.5/pkg/mapper/iac-providers/arm/config/mssql-server.go <==
/*
    Copyright (C) 2022 Tenable, Inc.

	Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

		http://www.apache.org/licenses/LICENSE-2.0

	Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
*/

package config

import (
	"github.com/tenable/terrascan/pkg/mapper/convert"
	fn "github.com/tenable/terrascan/pkg/mapper/iac-providers/arm/functions"
	"github.com/tenable/terrascan/pkg/mapper/iac-providers/arm/types"
)

const (
	armAdministratorLogin         = "administratorLogin"
	armAdministratorLoginPassword = "administratorLoginPassword"
	armMinimumTLSVersion          = "minimalTlsVersion"
)

const (
	tfAdministratorLogin         = "administrator_login"
	tfAdministratorLoginPassword = "administrator_login_password"
	tfMinimumTLSVersion          = "minimum_tls_version"
)

// MSSQLServerConfig returns config for azurerm_mssql_server
func MSSQLServerConfig(r types.Resource, vars, params map[string]interface{}) map[string]interface{} {
	return map[string]interface{}{
		tfLocation:                   fn.LookUpString(nil, params, r.Location),
		tfName:                       fn.LookUpString(nil, params, r.Name),
		tfTags:                       r.Tags,
		tfAdministratorLogin:         fn.LookUpString(vars, params, convert.ToString(r.Properties, armAdministratorLogin)),
		tfAdministratorLoginPassword: fn.LookUpString(vars, params, convert.ToString(r.Properties, armAdministratorLoginPassword)),
		tfMinimumTLSVersion:          fn.LookUpString(vars, params, convert.ToString(r.Properties, armMinimumTLSVersion)),
	}
}
